@@ -7,9 +7,8 @@ from pmb.types import Bootimg
 from pathlib import Path
 import os
 import pmb.helpers.cli
+import pmb.helpers.devices
 import pmb.helpers.run
-import pmb.aportgen.core
-import pmb.parse.apkindex
 import pmb.parse
 
 
@@ -25,10 +24,8 @@ def ask_for_architecture() -> Arch:
         if ret in architectures:
             return Arch.from_str(ret)
         logging.fatal(
-            "ERROR: Invalid architecture specified. If you want to"
-            " add a new architecture, edit"
-            " build_device_architectures in"
-            " pmb/config/__init__.py."
+            "ERROR: Invalid architecture specified. If you want to add a new architecture, edit "
+            "build_device_architectures in pmb/config/__init__.py."
         )
 
 
@@ -82,9 +79,7 @@ def ask_for_flash_method() -> str:
                 while True:
                     logging.info('Does the device use the "isolated recovery" or boot.img?')
                     logging.info(
-                        "<https://wiki.postmarketos.org/wiki"
-                        "/Deviceinfo_flash_methods#Isorec_or_bootimg"
-                        ".3F>"
+                        "<https://wiki.postmarketos.org/wiki/Deviceinfo_flash_methods#Isorec_or_bootimg.3F>"
                     )
                     heimdall_type = pmb.helpers.cli.ask("Type", heimdall_types, heimdall_types[0])
                     if heimdall_type in heimdall_types:
@@ -94,19 +89,16 @@ def ask_for_flash_method() -> str:
             return method
 
         logging.fatal(
-            "ERROR: Invalid flash method specified. If you want to"
-            " add a new flash method, edit flash_methods in"
-            " pmb/config/__init__.py."
+            "ERROR: Invalid flash method specified. If you want to add a new flash method, edit "
+            "flash_methods in pmb/config/__init__.py."
         )
 
 
 def ask_for_bootimg() -> Bootimg | None:
     logging.info(
-        "You can analyze a known working boot.img file to"
-        " automatically fill out the flasher information for your"
-        " deviceinfo file. Either specify the path to an image or"
-        " press return to skip this step (you can do it later with"
-        " 'pmbootstrap bootimg_analyze')."
+        "You can analyze a known working boot.img file to automatically fill out the flasher "
+        "information for your deviceinfo file. Either specify the path to an image or press return "
+        "to skip this step (you can do it later with 'pmbootstrap bootimg_analyze')."
     )
 
     while True:
@@ -124,8 +116,10 @@ def generate_deviceinfo_fastboot_content(bootimg: Bootimg | None = None) -> str:
     if bootimg is None:
         bootimg = Bootimg(
             cmdline="",
-            qcdt="false",
-            qcdt_type=None,
+            bootimg_qcdt="false",
+            bootimg_qcdt_type=None,
+            bootimg_qcdt_exynos_platform=None,
+            bootimg_qcdt_exynos_subtype=None,
             dtb_offset=None,
             dtb_second="false",
             base="",
@@ -145,14 +139,23 @@ def generate_deviceinfo_fastboot_content(bootimg: Bootimg | None = None) -> str:
         deviceinfo_flash_pagesize="{bootimg["pagesize"]}"
         """
 
-    for k in ["qcdt_type", "dtb_second", "mtk_label_kernel", "mtk_label_ramdisk", "header_version"]:
+    for k in [
+        "bootimg_qcdt",
+        "bootimg_qcdt_type",
+        "bootimg_qcdt_exynos_platform",
+        "bootimg_qcdt_exynos_subtype",
+        "dtb_second",
+        "mtk_label_kernel",
+        "mtk_label_ramdisk",
+        "header_version",
+    ]:
         v = bootimg[k]  # type: ignore
         if v:
             content += f"""\
             deviceinfo_{k}="{v}"
             """
 
-    if bootimg["header_version"] == "2":
+    if bootimg["header_version"] == 2:
         content += f"""\
         deviceinfo_append_dtb="false"
         deviceinfo_flash_offset_dtb="{bootimg["dtb_offset"]}"
@@ -241,8 +244,7 @@ def generate_deviceinfo(
     pmb.helpers.run.user(["mkdir", "-p", work / "aportgen"])
     path = work / "aportgen/deviceinfo"
     with open(path, "w", encoding="utf-8") as handle:
-        for line in content.rstrip().split("\n"):
-            handle.write(line.lstrip() + "\n")
+        handle.writelines(line.lstrip() + "\n" for line in content.rstrip().split("\n"))
 
 
 def generate_modules_initfs() -> None:
@@ -263,13 +265,23 @@ def generate_modules_initfs() -> None:
     pmb.helpers.run.user(["mkdir", "-p", work / "aportgen"])
     path = work / "aportgen/modules-initfs"
     with open(path, "w", encoding="utf-8") as handle:
-        for line in content.rstrip().split("\n"):
-            handle.write(line.lstrip() + "\n")
+        handle.writelines(line.lstrip() + "\n" for line in content.rstrip().split("\n"))
 
 
-def generate_apkbuild(pkgname: str, name: str, arch: Arch, flash_method: str) -> None:
+def generate_apkbuild(
+    pkgname: str,
+    name: str,
+    arch: Arch,
+    flash_method: str,
+    device_category: pmb.helpers.devices.DeviceCategory,
+) -> None:
     # Dependencies
-    depends = ["postmarketos-base", "linux-" + "-".join(pkgname.split("-")[1:])]
+    depends = ["postmarketos-base"]
+    if device_category == pmb.helpers.devices.DeviceCategory.DOWNSTREAM:
+        depends += ["linux-" + "-".join(pkgname.split("-")[1:]), "postmarketos-base-downstream"]
+    else:
+        depends += ["linux-CHANGEME"]
+
     if flash_method in ["fastboot", "heimdall-bootimg"]:
         depends.append("mkbootimg")
     if flash_method == "0xffff":
@@ -280,6 +292,7 @@ def generate_apkbuild(pkgname: str, name: str, arch: Arch, flash_method: str) ->
     depends_fmt = ("\n" + " " * 12).join(depends)
     content = f"""\
         # Reference: <https://postmarketos.org/devicepkg>
+        maintainer=""
         pkgname={pkgname}
         pkgdesc="{name}"
         pkgver=1
@@ -313,11 +326,12 @@ def generate_apkbuild(pkgname: str, name: str, arch: Arch, flash_method: str) ->
     pmb.helpers.run.user(["mkdir", "-p", work / "aportgen"])
     path = work / "aportgen/APKBUILD"
     with open(path, "w", encoding="utf-8") as handle:
-        for line in content.rstrip().split("\n"):
-            handle.write(line[8:].replace(" " * 4, "\t") + "\n")
+        handle.writelines(
+            line[8:].replace(" " * 4, "\t") + "\n" for line in content.rstrip().split("\n")
+        )
 
 
-def generate(pkgname: str) -> None:
+def generate(pkgname: str, device_category: pmb.helpers.devices.DeviceCategory) -> None:
     arch = ask_for_architecture()
     manufacturer = ask_for_manufacturer()
     name = ask_for_name(manufacturer)
@@ -341,4 +355,4 @@ def generate(pkgname: str) -> None:
         bootimg,
     )
     generate_modules_initfs()
-    generate_apkbuild(pkgname, name, arch, flash_method)
+    generate_apkbuild(pkgname, name, arch, flash_method, device_category)
