@@ -14,14 +14,8 @@ import pmb.build
 import pmb.chroot
 import pmb.config
 import pmb.helpers.apk
-import pmb.helpers.other
-import pmb.helpers.pmaports
-import pmb.helpers.repo
-import pmb.helpers.run
 from pmb.meta import Cache
 import pmb.parse.apkindex
-import pmb.parse.depends
-import pmb.parse.version
 from pmb.core import Chroot
 from pmb.core.context import get_context
 from pmb.types import PathString
@@ -45,17 +39,20 @@ def check_min_version(chroot: Chroot = Chroot.native()) -> None:
 
     installed_pkgs = installed(chroot)
 
-    if "apk-tools" not in installed_pkgs:
+    # Compare
+    try:
+        version_installed = installed_pkgs["apk-tools"].version
+    except KeyError:
         raise NonBugError(
             "ERROR: could not find apk-tools in chroot, run 'pmbootstrap zap' and try again"
         )
 
-    # Compare
-    version_installed = installed_pkgs["apk-tools"].version
-    pmb.helpers.apk.check_outdated(
-        version_installed,
-        "Delete your http cache and zap all chroots, then try again: 'pmbootstrap zap -hc'",
-    )
+    try:
+        pmb.helpers.apk.check_outdated(version_installed)
+    except RuntimeError as exception:
+        raise NonBugError(
+            f"{exception}. Delete your http cache and zap all chroots, then try again: 'pmbootstrap zap -hc'"
+        ) from exception
 
 
 def packages_split_to_add_del(packages: list[str]) -> tuple[list[str], list[str]]:
@@ -114,7 +111,7 @@ def packages_get_locally_built_apks(package_list: list[str], arch: Arch) -> list
                 break
 
         # Record all the packages we have visited so far
-        walked |= set([data_repo.pkgname, package])
+        walked |= {data_repo.pkgname, package}
         if data_repo.depends:
             # Add all dependencies to the list of packages to check, excluding
             # meta-deps like cmd:* and so:* as well as conflicts (!).
@@ -179,7 +176,10 @@ def install_run_apk(
         command = [*user_repo, *command]
 
         # Ignore missing repos before initial build (bpo#137)
-        if os.getenv("PMB_APK_FORCE_MISSING_REPOSITORIES") == "1":
+        if (
+            os.getenv("PMB_APK_FORCE_MISSING_REPOSITORIES") == "1"
+            or chroot.arch not in Arch.supported_binary()
+        ):
             command = ["--force-missing-repositories", *command]
 
         # Virtual package related commands don't actually install or remove
