@@ -6,15 +6,12 @@ from pmb.helpers import logging
 import os
 
 import pmb.chroot
-import pmb.chroot.binfmt
-import pmb.chroot.apk
 import pmb.config
 import pmb.config.workdir
 import pmb.helpers.apk_static
 import pmb.helpers.apk
 import pmb.helpers.repo
 import pmb.helpers.run
-import pmb.helpers.other
 from pmb.core import Chroot, ChrootType
 from pmb.core.context import get_context
 from pmb.types import PathString
