@@ -8,7 +8,6 @@ from pmb.core.arch import Arch
 from pmb.helpers import logging
 from pathlib import Path
 import tarfile
-import pmb.chroot.apk
 import pmb.helpers.package
 import pmb.helpers.repo
 import pmb.parse.version
@@ -261,7 +260,7 @@ def parse(
     lines: Sequence[str]
     if tarfile.is_tarfile(path):
         with (
-            tarfile.open(path, "r:gz") as tar,  # type:ignore[union-attr]
+            tarfile.open(path, "r:gz") as tar,
             tar.extractfile(tar.getmember("APKINDEX")) as handle,  # type:ignore[union-attr]
         ):
             lines = handle.read().decode().splitlines()
@@ -481,8 +480,6 @@ def package(
     package_providers = providers(
         package, arch, must_exist, indexes, user_repository=user_repository
     )
-    if package in package_providers:
-        return package_providers[package]
 
     if package_providers:
         providers_priority = provider_highest_priority(package_providers, package)
