@@ -14,7 +14,7 @@ from pmb.types import PmbArgs, RunOutputTypeDefault
 from pmb.helpers.exceptions import NonBugError
 
 with contextlib.suppress(ImportError):
-    import argcomplete  # type:ignore[import-untyped]
+    import argcomplete
 
 import pmb.config
 import pmb.helpers.args
@@ -555,8 +555,11 @@ def arguments_qemu(subparser: argparse._SubParsersAction) -> argparse.ArgumentPa
     )
 
     ret.add_argument(
-        "--efi", action="store_true", help="Use EFI boot (default: direct kernel image boot)"
+        "--efi",
+        action="store_true",
+        help="Use EFI boot (default: direct kernel image boot if supported by arch)",
     )
+
     return ret
 
 
@@ -692,11 +695,15 @@ def arguments_kconfig(subparser: argparse._SubParsersAction) -> None:
         action="store_true",
         help="continue on errors instead of aborting on the first error",
     )
+    check.add_argument(
+        "--categories", help="a comma separated list of additional kconfig categories to check"
+    )
     add_kernel_arg(check, nargs="*")
 
     # "pmbootstrap kconfig edit"
     edit = sub.add_parser("edit", help="edit kernel aport config")
     edit.add_argument("--arch", choices=arch_choices, dest="arch", type=lambda x: Arch.from_str(x))
+    edit.add_argument("--fragment", help="fragment filename to save changes")
     edit_ui_chooser = edit.add_mutually_exclusive_group()
     edit_ui_chooser.add_argument(
         "-x",
@@ -725,6 +732,12 @@ def arguments_kconfig(subparser: argparse._SubParsersAction) -> None:
     )
     add_kernel_arg(migrate, nargs=1)
 
+    generate = sub.add_parser("generate", help="generate kernel config from fragments")
+    generate.add_argument(
+        "--arch", choices=arch_choices, dest="arch", type=lambda x: Arch.from_str(x)
+    )
+    add_kernel_arg(generate, nargs=1)
+
 
 def arguments_repo_missing(subparser: argparse._SubParsersAction) -> argparse.ArgumentParser:
     ret = subparser.add_parser(
@@ -796,9 +809,9 @@ def package_completer(
     parser: argparse.ArgumentParser | None = None,
     parsed_args: list[str] | None = None,
 ) -> set[str]:
-    packages = set(
+    packages = {
         package for package in pmb.helpers.pmaports.get_list() if package.startswith(prefix)
-    )
+    }
     return packages
 
 
@@ -892,10 +905,8 @@ def get_parser() -> argparse.ArgumentParser:
     parser.add_argument(
         "-t",
         "--timeout",
-        help="seconds after which processes"
-        " get killed that stopped writing any output (default:"
-        " 900)",
-        default=900,
+        help="seconds after which processes get killed that stopped writing any output (default: "
+        "no timeout unless the environment variable 'CI' is set, in which case it is 900)",
         type=float,
     )
     parser.add_argument(
