@@ -6,7 +6,7 @@ from pmb.core.arch import Arch
 from pmb.helpers import logging
 import shlex
 
-from pmb.types import PathString, PmbArgs
+from pmb.types import PathString, PmbArgs, RunOutputTypeDefault
 import pmb.helpers.run
 import pmb.helpers.run_core
 import pmb.parse.apkindex
@@ -30,7 +30,7 @@ def scp_abuild_key(args: PmbArgs, user: str, host: str, port: str) -> None:
 
     logging.info(f"Copying signing key ({key_name}) to {user}@{host}")
     command: list[PathString] = ["scp", "-P", port, key, f"{user}@{host}:/tmp"]
-    pmb.helpers.run.user(command, output="interactive")
+    pmb.helpers.run.user(command, output=RunOutputTypeDefault.INTERACTIVE)
 
     logging.info(f"Installing signing key at {user}@{host}")
     keyname = os.path.join("/tmp", os.path.basename(key))
@@ -43,7 +43,7 @@ def scp_abuild_key(args: PmbArgs, user: str, host: str, port: str) -> None:
     remote_cmd = pmb.helpers.run_core.flat_cmd([remote_cmd_l])
     full_cmd = shlex.quote(f"{su_cmd} {remote_cmd}")
     command = ["ssh", "-t", "-p", port, f"{user}@{host}", f"sh -c {full_cmd}"]
-    pmb.helpers.run.user(command, output="tui")
+    pmb.helpers.run.user(command, output=RunOutputTypeDefault.TUI)
 
 
 def ssh_find_arch(args: PmbArgs, user: str, host: str, port: str) -> Arch:
@@ -63,7 +63,14 @@ def ssh_find_arch(args: PmbArgs, user: str, host: str, port: str) -> Arch:
     return alpine_architecture
 
 
-def ssh_install_apks(args: PmbArgs, user: str, host: str, port: str, paths: list[Path]) -> None:
+def ssh_install_apks(
+    args: PmbArgs,
+    user: str,
+    host: str,
+    port: str,
+    paths: list[Path],
+    install_offline: bool,
+) -> None:
     """Copy binary packages via SCP and install them via SSH.
     :param user: target device ssh username
     :param host: target device ssh hostname
@@ -71,22 +78,23 @@ def ssh_install_apks(args: PmbArgs, user: str, host: str, port: str, paths: list
     :param paths: list of absolute paths to locally stored apks
     """
 
-    remote_paths = []
-    for path in paths:
-        remote_paths.append(os.path.join("/tmp", os.path.basename(path)))
+    remote_paths = [os.path.join("/tmp", os.path.basename(path)) for path in paths]
 
     logging.info(f"Copying packages to {user}@{host}")
     command: list[PathString] = ["scp", "-P", port, *paths, f"{user}@{host}:/tmp"]
-    pmb.helpers.run.user(command, output="interactive")
+    pmb.helpers.run.user(command, output=RunOutputTypeDefault.INTERACTIVE)
 
     logging.info(f"Installing packages at {user}@{host}")
-    add_cmd_list = ["apk", "--wait", "30", "add", *remote_paths]
+    add_cmd_list = ["apk", "--wait", "30", "--timeout", "5"]
+    if install_offline:
+        add_cmd_list.append("--no-network")
+    add_cmd_list.extend(["add", *remote_paths])
     add_cmd = pmb.helpers.run_core.flat_cmd([add_cmd_list])
     clean_cmd = pmb.helpers.run_core.flat_cmd([["rm", *remote_paths]])
     add_cmd_complete = shlex.quote(f"{su_cmd} {add_cmd} rc=$?; {clean_cmd} exit $rc")
     # Run apk command in a subshell in case the foreign device has a non-POSIX shell.
     command = ["ssh", "-t", "-p", port, f"{user}@{host}", f"sh -c {add_cmd_complete}"]
-    pmb.helpers.run.user(command, output="tui")
+    pmb.helpers.run.user(command, output=RunOutputTypeDefault.TUI)
 
 
 def sideload(
@@ -108,21 +116,30 @@ def sideload(
     :param pkgnames: list of pkgnames to be built"""
 
     paths = []
-    channel: str = pmb.config.pmaports.read_config()["channel"]
 
     if arch is None:
         arch = ssh_find_arch(args, user, host, port)
 
     context = get_context()
     to_build = []
+    install_offline = True
     for pkgname in pkgnames:
         data_repo = pmb.parse.apkindex.package(pkgname, arch, True)
 
         if data_repo is None:
             raise RuntimeError(f"Couldn't find APKINDEX data for {pkgname}!")
 
+        base_aports, _ = pmb.build.get_apkbuild(pkgname)
+        channel = pmb.config.pmaports.read_config(base_aports)["channel"]
+
         apk_file = f"{pkgname}-{data_repo.version}.apk"
         host_path = context.config.work / "packages" / channel / arch / apk_file
+
+        # If none of the packages have dependencies then we can run apk with
+        # --no-network to avoid spurious APKINDEX updates
+        if data_repo.depends:
+            install_offline = False
+
         if not host_path.is_file():
             to_build.append(pkgname)
 
@@ -138,4 +155,4 @@ def sideload(
     if copy_key:
         scp_abuild_key(args, user, host, port)
 
-    ssh_install_apks(args, user, host, port, paths)
+    ssh_install_apks(args, user, host, port, paths, install_offline)
